@@ -1,7 +1,6 @@
 module Specs.BySubject.UsageError.SessionSpec where
 
 import Hasql.Pool
-import Hasql.Session qualified as Session
 import Helpers.Scripts qualified as Scripts
 import Helpers.Sessions qualified as Sessions
 import Test.Hspec
@@ -9,9 +8,9 @@ import Prelude
 
 spec :: SpecWith Scripts.ScopeParams
 spec = do
-  it "Simulation of connection error works" \scopeParams ->
+  it "Bad SQL query triggers error" \scopeParams ->
     Scripts.onAutotaggedPool 1 10 1_800 1_800 scopeParams \_ pool -> do
-      res <- use pool $ Sessions.closeConn >> Sessions.selectOne
+      res <- use pool Sessions.badQuery
       shouldSatisfy res $ \case
-        Left (SessionUsageError (Session.QueryError _ _ (Session.ClientError _))) -> True
+        Left (SessionUsageError _) -> True
         _ -> False
